function [SE,ME,BE,ecode] = fem_drkell(X,Y)
% Elliptische RWP, kubischer Ansatz nach ZIENKIEWICZ
% vgl. SCHWARZ: FEM
% liefert die Elementmatrizen SE(9,9) und ME(9,9) sowie
% den Elementvektor BE(9) fuer ein Dreieckelement
% INPUT:
%        X,Y die drei Eckenkoordinatenpaare
%        ecode = 1 bei falscher Orientierung

SE = zeros(9,9);
ME = zeros(9,9);
BE = zeros(9,1);
S1 = [400   6  62  -392  76  -58   -8  -50   4;
        6  21  -3   -18  -6   -3   12    3  -6;
       62  -3  13   -58  14  -11   -4  -13   2;
     -392 -18 -58   400 -68   62   -8   46   4;
       76  -6  14   -68  28  -10   -8  -14   4;
      -58  -3 -11    62 -10   13   -4   11   2;
       -8  12  -4    -8  -8   -4   16    4  -8;
      -50   3 -13    46 -14   11    4   25  -2;
        4  -6   2     4   4    2   -8   -2   4];

S2 = [784  64  64  -392  88 -120 -392 -120  88;
       64   9  17   -68  10  -19    4  -11  -2;
       64  17   9     4  -2  -11  -68  -19  10;
     -392 -68   4    16  -8   60  376   60 -80;
       88  10  -2    -8   4    6  -80   -6  16;
     -120 -19 -11    60   6   17   60   13  -6;
     -392   4 -68   376 -80   60   16   60  -8;
     -120 -11 -19    60  -6   13   60   17   6;
       88  -2  10   -80  16   -6   -8    6   4];

S3 = [400  62   6    -8   4  -50 -392  -58  76;
       62  13  -3    -4   2  -13  -58  -11  14;
        6  -3  21    12  -6    3  -18   -3  -6;
       -8  -4  12    16  -8    4   -8   -4  -8;
        4   2  -6    -8   4   -2    4    2   4;
      -50 -13   3     4  -2   25   46   11 -14;
     -392 -58 -18    -8   4   46  400   62 -68;
      -58 -11  -3    -4   2   11   62   13 -10;
       76  14  -6    -8   4  -14  -68  -10  28];

S4 = [1936  208  208  712  -212    76   712   76  -212;
       208   31   19  136   -38    13    76   11   -24;
       208   19   31   76   -24    11   136   13   -38;
       712  136   76 1936  -416   208   712  136  -212;
      -212  -38  -24 -416   100   -50  -212  -38    62;
        76   13   11  208   -50    31   136   25   -38;
       712   76  136  712  -212   136  1936  208  -416;
        76   11   13  136   -38    25   208   31   -50;
      -212  -24  -38 -212    62   -38  -416  -50   100];

SB = [8;  1;  1;  8; -2;  1;  8;  1; -2];
ecode = 0;
X21 = X(2) - X(1); X31 = X(3) - X(1);
Y21 = Y(2) - Y(1); Y31 = Y(3) - Y(1);
DET = X21*Y31 - X31*Y21;
if DET <= 0, ecode = 1; else
  A  =  (X31*X31 + Y31*Y31)/DET;
  B  = -(X31*X21 + Y31*Y21)/DET;
  C  =  (X21*X21 + Y21*Y21)/DET;
  SE =  (A*S1 + B*S2 + C*S3)/720;
  ME =  DET*S4/20160;
  BE =  DET*SB/48;
end
for J = [2  5  8]
  for I = 1:9
    H1        = X21*SE(I,J) + X31*SE(I,J+1);
    SE(I,J+1) = Y21*SE(I,J) + Y31*SE(I,J+1);
    SE(I,J)   = H1;
    H1        = X21*ME(I,J) + X31*ME(I,J+1);
    ME(I,J+1) = Y21*ME(I,J) + Y31*ME(I,J+1);
    ME(I,J)   = H1;
  end
end
for I = [2  5 8]
  for J = 1:9
    H1        = X21*SE(I,J) + X31*SE(I+1,J);
    SE(I+1,J) = Y21*SE(I,J) + Y31*SE(I+1,J);
    SE(I,J)   = H1;
    H1        = X21*ME(I,J) + X31*ME(I+1,J);
    ME(I+1,J) = Y21*ME(I,J) + Y31*ME(I+1,J);
    ME(I,J)   = H1;
  end
  H1          = X21*BE(I) + X31*BE(I+1);
  BE(I+1)     = Y21*BE(I) + Y31*BE(I+1);
  BE(I)       = H1;
end
