function [SE,ME,BE,ecode] = fem_pakpla(XK,YK,E,NU,H,P)
% -- GEKELER: FINITE ELEMENTE, vgl. SCHWARZ: FEM ------------
% LIEFERT DIE ELEMENTMATRIZEN SE(12,12) UND ME(12,12) SOWIE DEN
% ELEMENTVEKTOR BE(12) FUER EIN NICHTKONFORMES PARALLELOGRAMM-
% ELEMENT, KUBISCHER ANSATZ DER SERENDIPITY-KLASSE
% PLATTENPROBLEME
% XK, YK : DIE DREI ECKENKOORDINATENPAARE
% E : ELASTIZITAETSMODUL,  NU : POISSONZAHL
% H : DICKE DES ELEMENTES,  P : BELASTUNG DES ELEMENTES
% ecode : WIRD BEI FALSCHER ORIENTIERUNG GLEICH 1 GESETZT
% ------------------------------------------------------------
SE = zeros(12,12); ME = zeros(12,12); BE = zeros(12,1);
S1 = [24,12,0,-24,12,0,-12,6,0,12,6,0, 8,0,-12,4, 0,-6,2,...
      0,6,4,0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24,-12,0,12,...
     -6,0,-12,-6,0, 8,0, -6,4,0,6,2,0, 0, 0, 0, 0, 0, 0, 0,...
     24,-12,0,-24,-12,0, 8,0,12,4,0,  0, 0, 0, 0,  24,12,0,...
      8, 0, 0];
S2 = [0, 0, 0, 0, 0, 0, 0, 12, 0, 0,-12, 0, 6, 1, 0, 0, -1,...
     -12, 6, 1, 12, 0, -1, 0, 0, -1, 0, 0, 1, 0, 0, -1, 0,...
       0, 0, 0, 0, -12, 0, 0, 12, 0, -6, 1, 12, 0,-1,-12,...
      -6, 1, 0, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6,...
       1, 0, 0, -1, 0, 0, -1, 0, 0, 0, 0, -6,  1, 0];
S3 = [6, 3, 3, -6, 0, -3, 6, 0, 0, -6, -3, 0, 0,3,...
      0, 0, 0, 0, 0, 0,-3, 0, 0, 0,-3, 0, 0, 0, 0, 0, 0, 0, 0,...
      6,-3, 3, -6, 3, 0, 6, 0, 0, 0, -3, 3, 0, 0, 0, 0, 0,...
      0, 0, 0, 0, 0, 0, 0,  6,-3, -3,-6,0,  3, 0,3,0, 0, 0,...
      0, 3, 0, 0, 6, 3, -3, 0, -3, 0];
S4 = [42,3,3,-42,3,-3,42,-3,-3,-42,-3,3,  4,0,-3,...
      -1,0,3,1,0,-3,-4,0,  4,-3,0,-4,3,0,1,-3,0,-1,  42,-3,3,...
     -42,3,3,42,3,-3,  4,0,3,-4,0,-3,1,0,  4,-3,0,-1,3,0,1,...
      42,-3,-3,-42,-3,3,  4,0,3,-1,0,  4,3,0,-4,  42,3,-3,  4,...
       0,  4];
S5 = [0, 0, 0, 0, 0 ,-12,0,0,12, 0, 0, 0, 0,1,0,0,-1,0,0,1,...
      0,0,-1, 6,12,-1,0,-12,1,6,0,-1,0, 0, 0, 0, 0, 0, 0, 0,...
      0 ,-12, 0,1, 0, 0, -1, 0, 0, 1, -6, 0, -1, 0, 12, 1,...
     -6, 0, 0, 0, 0, 0, 12, 0, 1, 0, 0,-1, 6,-12,-1,0, 0, 0, 0,...
      0,1,  -6];
S6 = [24, 0, 12, 12, 0, 6, -12, 0, 6, -24, 0, 12, 0, 0, 0,...
       0, 0, 0, 0, 0, 0, 0, 0,  8, 6, 0, 4,-6, 0, 2, -12, 0, 4,...
      24,0,12,-24,0,12,-12,0,6, 0, 0, 0, 0, 0, 0, 0, 0,...
       8,-12,0,4,-6,0,2, 24, 0,-12,12,0,-6, 0, 0, 0, 0, 0,...
       8,-6,0,4, 24,0,-12, 0,0, 8];
S7 = [3454,461,461,1226,-274,199,394,-116,-116,1226,199,-274,...
      80,63,274,-60,42,116,-30,-28,199,40,-42,  80,199,-42,...
      40,116,-28,-30,274,42,-60,  3454,-461,461,1226,-199,-274,...
      394,116,-116,  80,-63,-199,40,42,-116,-30,28,  80,274,...
      -42,-60,116,28,-30,  3454,-461,-461,1226,274,-199, 80,63,...
     -274,-60,42,  80,-199,-42,40,  3454,461,-461, 80,-63, 80];
SB = [6,1,1,6,-1,1,6,-1,-1,6,1,-1];
ecode = 0;
X21 = XK(2) - XK(1); X31 = XK(3) - XK(1);
Y21 = YK(2) - YK(1); Y31 = YK(3) - YK(1);
D = E * H * H * H /(12 * (1 - NU * NU));
DET = X21 * Y31 - X31 * Y21;
if DET <= 0
   ecode = 1;
else
   DET3 = DET * DET * DET * 6 / D;
   H1 = X31 * X31 + Y31 * Y31;
   H2 = X21 * X31 + Y21 * Y31;
   H3 = X21 * X21 + Y21 * Y21;
   A1 = H1 * H1 / DET3;
   A2 = - H2 * H1 / DET3;
   A3 = 2 * (H2 * H2 + NU * DET * DET) / DET3;
   A4 = (4 * H2 * H2 + 2 * (1 - NU) * DET * DET)/DET3/5;
   A5 = - H2 * H3 / DET3;
   A6 = H3 * H3 / DET3;
   IJ = 0;
   for I = 1:12
      for J = I:12
         IJ = IJ + 1;
         SE(I,J) = A1 * S1(IJ) + A2 * S2(IJ) + A3 * S3(IJ)...
                  + A4 * S4(IJ) + A5 * S5(IJ) + A6 * S6(IJ);
         SE(J,I) = SE(I,J);
         ME(I,J) = DET * S7(IJ) / 25200;
         ME(J,I) = ME(I,J);
      end
      BE(I) = P * SB(I) * DET / 24;
   end
   for J = [2,5,8,11]
      for I = 1:12
         H1 = X21 * SE(I,J) + X31 * SE(I,J+1);
         SE(I,J+1) = Y21 * SE(I,J) + Y31 * SE(I,J+1);
         SE(I,J) = H1;
         H1 = X21 * ME(I,J) + X31 * ME(I,J+1);
         ME(I,J+1) = Y21 * ME(I,J) + Y31 * ME(I,J+1);
         ME(I,J) = H1;
      end
   end
   for I = [2,5,8,11]
      for J = 1:12
         H1 = X21 * SE(I,J) + X31 * SE(I+1,J);
         SE(I+1,J) = Y21 * SE(I,J) + Y31 * SE(I+1,J);
         SE(I,J) = H1;
         H1 = X21 * ME(I,J) + X31 * ME(I+1,J);
         ME(I+1,J) = Y21 * ME(I,J) + Y31 * ME(I+1,J);
         ME(I,J) = H1;
      end
      H1 = X21 * BE(I) + X31 * BE(I+1);
      BE(I+1) = Y21 * BE(I) + Y31 * BE(I+1);
      BE(I) = H1;
   end
end
